import { Observable } from "rxjs";
import { App } from "../globals";
import { RightRole } from "../services";
/** Framework exploration capabilities offered to the client. */
export interface IExplorerFramework {
    /**
     * Create a new context to explore resources produced by an application.
     * @param types Types of resource to be managed in this context.
     * @param app Application which creates the new context.
     */
    createContext(types: ResourceType[], app: App): IExplorerContext;
    /**
     * Retrieve the underlying communication bus.
     */
    getBus(): IBus;
}
/** Context to explore resources from an application. */
export interface IExplorerContext {
    /**
     * @return true, if the context is initialized.
     */
    isInitialized(): boolean;
    /**
     * @return The initialized search context, or undefined if initialize() has not been called before.
     */
    getContext(): IContext | undefined;
    /**
     * @return search parameters in the current context, modifiable before any call to getResources() or initialize().
     */
    getSearchParameters(): ISearchParameters;
    /**
     * @return a stream of (search,result) tuples, generated by initialize() and getResources() which should be called by your searches or pagination.
     */
    latestResources(): Observable<{
        input: ISearchParameters;
        output: ISearchResults;
    }>;
    /**
     * Clear and reset the underlying context.
     */
    clear(): void;
    /**
     * Retrieve the first page of listed resources from the server.
     * Observers of the latestResources() will be notified.
     * Search parameters can be adjusted beforehand, @see getSearchParameters().
     * @return
     */
    initialize(): Promise<IContext>;
    /**
     * Retrieve a page of listed resources from the server.
     * Observers of the latestResources() will be notified.
     * Search parameters can be adjusted beforehand, @see getSearchParameters().
     */
    getResources(): Promise<GetResourcesResult>;
    /**
     * Retrieve subfolders of a parent folder, from the server.
     * @param parentId ID of the parent folder.
     */
    getSubFolders(parentId: ID): Promise<GetSubFoldersResult>;
    /**
     * Create a new [sub]folder.
     * @param resourceType Type of resources the created folder will contain.
     * @param parentId ID of the parent folder, or "default" for the root folder.
     * @param name Name of the created folder.
     */
    createFolder(resourceType: ResourceType, parentId: ID | "default", name: string): Promise<CreateFolderResult>;
    /**
     * Modify the properties of a folder.
     * @param folderId ID of the folder to modify.
     * @param resourceType Type of resources the modified folder will contain.
     * @param parentId ID of the parent folder.
     * @param name Name of the folder.
     */
    updateFolder(folderId: ID, resourceType: ResourceType, parentId: ID | "default", name: string): Promise<UpdateFolderResult>;
    /**
     * Copy resources and folders into a folder.
     * @param targetId ID of the destination folder.
     * @param resourceIds Array of resources ID to copy.
     * @param folderIds Array of folders ID to copy.
     */
    copy(targetId: ID, resourceIds: ID[], folderIds: ID[]): Promise<void>;
    /**
     * Move resources and folders into a folder.
     * @param targetId ID of the destination folder.
     * @param resourceIds Array of resources ID to move.
     * @param folderIds Array of folders ID to move.
     */
    move(targetId: ID, resourceIds: ID[], folderIds: ID[]): Promise<void>;
    /**
     * Delete resources and folders.
     * @param resourceIds Array of resources ID to delete.
     * @param folderIds Array of folders ID to delete.
     */
    delete(resourceIds: ID[], folderIds: ID[]): Promise<void>;
    /**
     * Trash / Untrash resources and folders.
     * @param trash boolean set status trash or untrash
     * @param resourceIds Array of resources ID to delete.
     * @param folderIds Array of folders ID to delete.
     */
    trash(trash: boolean, resourceIds: ID[], folderIds: ID[]): Promise<void>;
    /** Retrieves which properties of the resource(s) are manageable. */
    manageProperties(resourceType: ResourceType, resources: IResource[]): Promise<ManagePropertiesResult>;
    /** Update managed properties. */
    updateProperties(resourceType: ResourceType, resources: IResource[], props: {
        [key in PropKeyType]?: string;
    }): Promise<UpdatePropertiesResult>;
    /** Publish to Library */
    publish(resourceType: ResourceType, parameters: PublishParameters): Promise<PublishResult>;
}
export declare const RESOURCE: {
    readonly FOLDER: "folder";
    readonly BLOG: "blog";
    readonly EXERCISE: "exercise";
    readonly MINDMAP: "mindmap";
};
export declare type ResourceType = (typeof RESOURCE)[keyof typeof RESOURCE];
export declare const appNameForResource: {
    [R in ResourceType]: App;
};
export declare const ACTION: {
    readonly INITIALIZE: "initialize";
    readonly SEARCH: "search";
    readonly CREATE: "create";
    readonly OPEN: "open";
    readonly MANAGE: "manage";
    readonly UPD_PROPS: "properties";
    readonly COMMENT: "comment";
    readonly DELETE: "delete";
    readonly TRASH: "trash";
    readonly RESTORE: "restore";
    readonly MOVE: "move";
    readonly COPY: "copy";
    readonly EXPORT: "export";
    readonly SHARE: "share";
    readonly PRINT: "print";
    readonly PAGES_LIST: "pages_list";
    readonly DISTRIBUTE: "distribute";
    readonly REGISTER: "register";
    readonly PUBLISH: "publish";
    readonly PUBLISH_MOODLE: "publish_moodle";
};
export declare type ActionType = (typeof ACTION)[keyof typeof ACTION];
export declare const FOLDER: {
    readonly BIN: "bin";
    readonly DEFAULT: "default";
};
export declare type FolderType = (typeof FOLDER)[keyof typeof FOLDER];
export declare const BOOLEAN_FILTER: {
    readonly OWNER: "owner";
    readonly SHARED: "shared";
    readonly PUBLIC: "public";
    readonly FAVORITE: "favorite";
};
export declare type BooleanFilterType = (typeof BOOLEAN_FILTER)[keyof typeof BOOLEAN_FILTER];
export declare const STRING_FILTER: {};
export declare type StringFilterType = (typeof STRING_FILTER)[keyof typeof STRING_FILTER];
export declare const SORT_ORDER: {
    readonly ASC: "asc";
    readonly DESC: "desc";
};
export declare type SortOrderType = (typeof SORT_ORDER)[keyof typeof SORT_ORDER];
export declare const SORT_BY: {
    readonly NAME: "name";
    readonly MODIFY_DATE: "updatedAt";
    readonly CREATEDAT: "createdAt";
    readonly APPLICATION: "application";
    readonly RESOURCE_TYPE: "resourceType";
};
export declare type SortByType = (typeof SORT_BY)[keyof typeof SORT_BY];
export declare type ID = string;
export declare type StringFilterValue = {
    value: string;
    i18n: string;
};
export declare const PROP_KEY: {
    readonly TITLE: "title";
    readonly IMAGE: "image";
    readonly COLOR: "color";
    readonly DESCRIPTION: "description";
    readonly URL: "url";
};
export declare type PropKeyType = (typeof PROP_KEY)[keyof typeof PROP_KEY];
export declare const PROP_MODE: {
    readonly READONLY: "RO";
    readonly READWRITE: "RW";
};
export declare type PropModeType = (typeof PROP_MODE)[keyof typeof PROP_MODE];
export declare const PROP_TYPE: {
    readonly TEXT: "text";
    readonly NUMBER: "number";
    readonly DATE: "date";
    readonly IMAGE: "image";
};
export declare type PropTypeType = (typeof PROP_TYPE)[keyof typeof PROP_TYPE];
export declare const PROP_FORMAT: {
    readonly PLAIN: "plain";
};
export declare type PropFormatType = (typeof PROP_FORMAT)[keyof typeof PROP_FORMAT];
export declare type SearchResultHandler = (input: IActionParameters, output: IActionResult) => void;
export interface ISearchParameters {
    types: ResourceType[];
    app: App;
    filters: FilterValues;
    orders?: OrderValues;
    pagination: IPagination;
    search?: String;
    trashed?: boolean;
}
export interface ISearchResults {
    folders: IFolder[];
    pagination: IPagination;
    resources: IResource[];
    searchConfig?: {
        minLength: number;
    };
}
export interface IContext extends ISearchResults {
    preferences: IPreferences;
}
export interface IAction {
    id: ActionType;
    available: boolean;
    target?: "actionbar";
    workflow: string;
    right?: RightRole;
}
export interface IFolder {
    id: ID;
    parentId: ID;
    name: string;
    type: FolderType | ID;
    childNumber: number;
    trashed: boolean;
    rights: string[];
    ancestors: string[];
}
export interface IFilter {
    id: BooleanFilterType | StringFilterType;
    defaultValue?: string | string[] | boolean | boolean[];
    values?: StringFilterValue[];
}
export interface IOrder {
    id: SortByType;
    defaultValue?: SortOrderType;
    i18n: string;
}
export interface IPagination {
    startIdx: number;
    maxIdx?: number;
    pageSize: number;
}
export interface IProperty {
    key: PropKeyType;
    i18n?: string;
}
export interface IResource {
    application: App;
    assetId: string;
    creatorId: string;
    creatorName: string;
    comments?: number;
    createdAt: string;
    favorite?: boolean;
    folderIds?: ID[];
    id: ID;
    modifiedAt: string;
    modifierId: ID;
    modifierName: string;
    name: string;
    slug?: string;
    public?: boolean;
    shared?: boolean;
    thumbnail: string;
    updatedAt: string;
    views?: number;
    trashed: boolean;
    trashedBy?: string[];
    rights: RightStringified[];
    description: string;
}
export declare type RightStringified = string;
export interface IPreferences {
    view: "card" | "list";
}
export interface IActionParameters {
}
export declare type GetContextParameters = IActionParameters & ISearchParameters;
export declare type GetResourcesParameters = IActionParameters & ISearchParameters;
export declare type CreateFolderParameters = IActionParameters & {
    app: App;
    type: ResourceType;
    parentId: ID | "default";
    name: string;
};
export declare type UpdateFolderParameters = IActionParameters & {
    folderId: ID;
    app: App;
    type: ResourceType;
    parentId: ID | "default";
    name: string;
};
export declare type OpenParameters = IActionParameters & {
    resourceId: ID;
};
export declare type PrintParameters = IActionParameters & {
    resourceId: ID;
    withComments?: boolean;
};
export declare type CopyParameters = IActionParameters & {
    application: string;
    folderId: ID;
    resourceIds: ID[];
    folderIds: ID[];
};
export declare type MoveParameters = IActionParameters & {
    application: string;
    folderId: ID;
    resourceIds: ID[];
    folderIds: ID[];
};
export declare type DeleteParameters = IActionParameters & {
    application: string;
    resourceType: string;
    resourceIds: ID[];
    folderIds: ID[];
};
export declare type TrashParameters = IActionParameters & {
    trash: boolean;
    application: string;
    resourceType: string;
    resourceIds: ID[];
    folderIds: ID[];
};
export declare type ManagePropertiesParameters = IActionParameters & {
    resources: IResource[];
};
export declare type UpdatePropertiesParameters = IActionParameters & {
    resources: IResource[];
    props: {
        [key in PropKeyType]?: string;
    };
};
export declare type PublishParameters = IActionParameters & {
    userId: string | undefined;
    title: string;
    cover: Blob;
    language: string;
    activityType: string[];
    subjectArea: string[];
    age: [string, string];
    description: string;
    keyWords: string;
    application: string | undefined;
    licence: string;
    teacherAvatar: Blob;
    resourceId: string;
    resourceEntId: string;
    userStructureName: string;
};
export declare type FilterValues = {
    [B in BooleanFilterType]?: boolean;
} & {
    [S in StringFilterType]?: string;
} & {
    folder?: ID;
};
export declare type OrderValues = {
    [O in SortByType]?: SortOrderType;
};
export interface IActionResult {
}
export declare type GetContextResult = IActionResult & IContext;
export declare type GetResourcesResult = IActionResult & ISearchResults;
export declare type GetSubFoldersResult = IActionResult & {
    folders: IFolder[];
};
export declare type CreateFolderResult = IActionResult & IFolder & {
    createdAt: string;
    creator_id?: string;
};
export declare type UpdateFolderResult = CreateFolderResult & {
    updatedAt: string;
    parentId: ID | "default";
};
export declare type ManagePropertiesResult = IActionResult & {
    genericProps: IProperty[];
};
export declare type UpdatePropertiesResult = IActionResult & {
    resources: IResource[];
};
export declare type PublishResult = IActionResult & {
    details: {
        application: string;
        created_at: string;
        description: string;
        front_url: string;
        id: string;
        title: string;
    };
    message: string;
    reason: string;
    success: boolean;
};
export interface IBus {
    /**
     * Ask any agent on the bus to perform an action on a type of resource.
     * @param res The type of resource in concern.
     * @param action The action requested on the type of resource.
     * @param parameters The [specific] parameters for the action.
     * @return The result of the action from the agent.
     */
    publish(res: ResourceType, action: ActionType, parameters: IActionParameters): Promise<IActionResult>;
    /**
     * Subscribe to ActionResults any agent produces for a given ResourceType and ActionType.
     * @param res The type of resource in concern.
     * @param action The action in concern.
     * @return A stream of IActionParameters and IActionResult
     */
    subscribe(res: ResourceType, action: ActionType): Observable<{
        input: IActionParameters;
        output: IActionResult;
    }>;
    /** Register an agent able to resolve an action on a type of resource. */
    setAgentFor(res: ResourceType, action: ActionType, agent: IBusAgent): void;
    /** Retrieve an agent able to resolve an action on a type of resource. */
    getAgentFor(res: ResourceType, action: ActionType): IBusAgent | null;
}
export interface IBusAgent {
    /** Ask this agent to resolve an action. */
    activate(res: ResourceType, action: ActionType, parameters: IActionParameters): Promise<IActionResult>;
}
